<?php
/*
 * Plugin Name:   MaxBlogPress Favicon
 * Version:       2.0.3
 * Plugin URI:    http://www.maxblogpress.com/plugins/mfi/
 * Description:   Easily add favicon to your blog without editing any wordpress files.
 * Author:        MaxBlogPress
 * Author URI:    http://www.maxblogpress.com
 */
 
define('MBPFAVICON_NAME', 'MaxBlogPress Favicon');	// Name of the Plugin
define('MBPFAVICON_VERSION', '2.0.3');				// Current version of the Plugin
$mfi_abspath = str_replace("\\","/",ABSPATH);       // required for Windows
define('MFI_ABSPATH', $mfi_abspath);

/**
 * MBPFavIcon - MaxBlogPress Favicon Class
 * Holds all the necessary functions and variables
 */
class MBPFavIcon 
{
    /////////////////////////////////////////////////
    // PUBLIC VARIABLES
    /////////////////////////////////////////////////
    /**
     * MaxBlogPress Favicon plugin path
     * @var string
     */
	var $mbpfavicon_path = '';
	
    /**
     * MaxBlogPress Favicon plugin's icon directory absolute path
     * @var string
     */
	var $mbpfavicon_fullpath = '';
	
    /**
     * MaxBlogPress Favicon plugin's icon directory full path
     * @var string
     */
	var $mbpfavicon_dir_path = '';
	
    /**
     * MaxBlogPress Favicon image
     * @var string
     */
	var $mbpfavicon = '';

	/**
	 * Constructor. Adds MaxBlogPress Favicon plugin's actions/filters.
	 * @access public
	 */
	function MBPFavIcon() { 
		global $wp_version;
		$this->mbpfavicon_path     = preg_replace('/^.*wp-content[\\\\\/]plugins[\\\\\/]/', '', __FILE__);
		$this->mbpfavicon_path     = str_replace('\\','/',$this->mbpfavicon_path);
		$this->siteurl             = get_bloginfo('wpurl');
		$this->siteurl             = (strpos($this->siteurl,'http://') === false) ? get_bloginfo('siteurl') : $this->siteurl;
		$this->mbpfavicon_fullpath = $this->siteurl.'/wp-content/plugins/'.substr($this->mbpfavicon_path,0,strrpos($this->mbpfavicon_path,'/')).'/icons/';
		$curr_path  		       = str_replace("\\", "/", __FILE__);
		$this->mbpfavicon_dir_path = substr($curr_path, 0, strrpos($curr_path,'/')).'/icons/';

	    add_action('activate_'.$this->mbpfavicon_path, array(&$this, 'mbpfaviconActivate'));
		add_action('admin_menu', array(&$this, 'mbpfaviconAddMenu'));
		$this->mfi_activate = get_option('mfi_activate');
		$this->mbpfavicon = get_option('mbp_favicon');
		if ( $this->mfi_activate == 2 && $this->mbpfavicon != '' ) {
			if ( $wp_version < 2.1 ) {
				add_action('wp_head', array(&$this, 'mbpfaviconAdd'));
			} else {
				add_filter('get_header', array(&$this, 'mbpfaviconAddStart'));
				add_filter('get_footer', array(&$this, 'mbpfaviconAddEnd'));
			}
			add_action('template_redirect', array(&$this, 'mbpfaviconRedirect'));
			add_action('admin_head', array(&$this, 'mbpfaviconAdd'));
			add_action('rss2_head', array(&$this, 'mbpfaviconAddToRSS2Feed'));
			add_action('atom_head', array(&$this, 'mbpfaviconAddToAtomFeed'));
		}		
	}
	
	/**
	 * Called when plugin is activated. Adds option value to the options table.
	 * @access public
	 */
	function mbpfaviconActivate() {
		add_option('mfi_activate', 0);
		add_option('mbp_favicon', '', 'MaxBlogPress Favicon plugin option', 'no');
		return true;
	}
	
	/**
	 * Returns the correct favicon path
	 * @access public
	 */
	function mbpfaviconRedirect() {
		global $wpdb;
		if ( is_404() && strpos($_SERVER['REQUEST_URI'],'favicon.ico') !== false ) {
			$favicon_path = get_option('mbp_favicon');
			header( "Location: $favicon_path" );
		}
	}
	
	/**
	 * Returns the type/extension of image
	 * @access public
	 */
	function mbpfaviconType($faviconpath) {
		if ( preg_match("/\.gif$/i", $faviconpath) )     return 'gif';
		if ( preg_match("/\.ico$/i", $faviconpath) ) 	 return 'x-icon';
		if ( preg_match("/\.jp[e]?g$/i", $faviconpath) ) return 'jpg';
		if ( preg_match("/\.png$/i", $faviconpath) )	 return 'png';
		else return '';
	}
	
	/**
	 * Adds favicon to the rss2 feed
	 * @access public
	 */
	function mbpfaviconAddToRSS2Feed() {
		$mfi_rss  = '<image>'."\n";
		$mfi_rss .= '<link>'.get_bloginfo_rss('url').'</link>'."\n";
		$mfi_rss .= '<url>'.$this->mbpfavicon.'</url>'."\n";
		$mfi_rss .= '<title>'.get_bloginfo_rss('name').'</title>'."\n";
		$mfi_rss .= '</image>'."\n";
		echo $mfi_rss;
	}
	
	/**
	 * Adds favicon to the atom feed
	 * @access public
	 */
	function mbpfaviconAddToAtomFeed() {
		$mfi_atom  = '<icon>'.$this->mbpfavicon.'</icon>'."\n";
		$mfi_atom .= '<logo>'.$this->mbpfavicon.'</logo>'."\n";
		echo $mfi_atom;
	}
	
	/**
	 * Adds favicon
	 * @access public
	 */
	function mbpfaviconAdd($not_ver20='') {
		$favicon_type = $this->mbpfaviconType($this->mbpfavicon);
		if ( trim($favicon_type) != '' ) {
			$mfi_favicon = '<link rel="shortcut icon" href="'.$this->mbpfavicon.'" type="image/'.$favicon_type.'" />';
		} else {
			$mfi_favicon = '<link rel="shortcut icon" href="'.$this->mbpfavicon.'" />';
		}
		if ( $not_ver20 != '' ) {
			return $mfi_favicon;
		} else {
			echo "\n".$mfi_favicon."\n";
		}
	}
	
	/**
	 * Start Output Buffer
	 * @access public
	 */
	function mbpfaviconAddStart(){
		ob_start();
	}
	
	/**
	 * Adds favicon. Gets content from output buffer and displays
	 * @access public
	 */
	function mbpfaviconAddEnd(){
		$mfi_output  = ob_get_contents();
		ob_end_clean();
		$mfi_favicon = $this->mbpfaviconAdd(1);
		$mfi_output = str_replace("</head>", "\n $mfi_favicon \n </head>", $mfi_output);
		echo $mfi_output;
	}

	/**
	 * Adds "MBP Favicon" link to admin Options menu
	 * @access public 
	 */
	function mbpfaviconAddMenu() {
		add_options_page('MaxBlogPress Favicon', 'MBP Favicon', 'manage_options', $this->mbpfavicon_path, array(&$this, 'mbpfaviconOptionsPg'));
	}
	
	/**
	 * Creates favicon directory to upload icons
	 * @access public 
	 */
	function mbpfaviconMakeDir($mfi_dir) {
		$mfi_upload_path = MFI_ABSPATH.'wp-content/'.$mfi_dir;
		if ( is_admin() && !is_dir($mfi_upload_path) ) {
			@mkdir($mfi_upload_path);
		}
		return $mfi_upload_path;
	}
	
	/**
	 * Displays the page content for "MBP Favicon" Options submenu
	 * Carries out all the operations in Options page
	 * @access public 
	 */
	function mbpfaviconOptionsPg() {
		global $wpdb;
		$this->mbpfavicon_request = $_REQUEST['mbpfavicon'];
		
		$form_1 = 'mfi_reg_form_1';
		$form_2 = 'mfi_reg_form_2';
		// Activate the plugin if email already on list
		if ( trim($_GET['mbp_onlist']) == 1 ) { 
			$this->mfi_activate = 2;
			update_option('mfi_activate', $this->mfi_activate);
			$msg = 'Thank you for registering the plugin. It has been activated'; 
		} 
		// If registration form is successfully submitted
		if ( ((trim($_GET['submit']) != '' && trim($_GET['from']) != '') || trim($_GET['submit_again']) != '') && $this->mfi_activate != 2 ) { 
			update_option('mfi_name', $_GET['name']);
			update_option('mfi_email', $_GET['from']);
			$this->mfi_activate = 1;
			update_option('mfi_activate', $this->mfi_activate);
		}
		if ( intval($this->mfi_activate) == 0 ) { // First step of plugin registration
			$this->mfiRegister_1($form_1);
		} else if ( intval($this->mfi_activate) == 1 ) { // Second step of plugin registration
			$name  = get_option('mfi_name');
			$email = get_option('mfi_email');
			$this->mfiRegister_2($form_2,$name,$email);
		} else if ( intval($this->mfi_activate) == 2 ) { // Options page
			if ( $this->mbpfavicon_request['save'] ) {
				$success = '';
				$mfi_dir = 'mbp-favicon';
				$mfi_valid_file = array("image/x-icon", "image/png", "image/jpeg", "image/pjpeg", "image/gif", "image/bmp");
				if ( $this->mbpfavicon_request['link_type'] == 3 ) { // Upload from URL
					$mfi_upload_path = $this->mbpfaviconMakeDir($mfi_dir);
					$mfi_src_url     = trim($this->mbpfavicon_request['favicon_upload_2']);
					$mfi_src_info    = pathinfo($mfi_src_url);
					$mfi_src_file    = $mfi_src_info['basename'];
					$mfi_src_ext     = $mfi_src_info['extension'];
					if ( $mfi_src_ext == 'ico' || $mfi_src_ext == 'jpg' || $mfi_src_ext == 'gif' || $mfi_src_ext == 'png' || $mfi_src_ext == 'bmp' ) {
						$mfi_dest_url    = $mfi_upload_path.'/'.$mfi_src_file;
						$mfi_favicon_url = $this->siteurl.'/wp-content/'.$mfi_dir.'/'.$mfi_src_file; 
						if ( ini_get('allow_url_fopen') ) {
							@copy($mfi_src_url, $mfi_dest_url);
							$success = 1;
						} else if ( extension_loaded('curl') ) {
							$ch = curl_init();
							curl_setopt($ch, CURLOPT_URL, $mfi_src_url);
							curl_setopt($ch, CURLOPT_HEADER, false);
							curl_setopt($ch, CURLOPT_BINARYTRANSFER, true);
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
							set_time_limit(300); // 5 minutes for PHP
							curl_setopt($ch, CURLOPT_TIMEOUT, 300); // 5 minutes for CURL
							$mfi_outfile = fopen($mfi_dest_url, 'wb');
							curl_setopt($ch, CURLOPT_FILE, $mfi_outfile);
							curl_exec($ch);
							fclose($mfi_outfile);
							curl_close($ch); 	
							$success = 1;
						} else {
							$mfi_msg = "Favicon couldn't be uploaded from URL. 'URL file-access' and/or 'CURL' are/is disabled in your server.";
						}
					} else {
						$mfi_msg = 'Favicon couldn\'t be uploaded from URL. Invalid file type';
					}
					if ( $success == 1 ) {
						$this->mbpfavicon = $mfi_favicon_url;
						$mfi_msg = 'Favicon uploaded from URL and activated.';
					} else {
						$mfi_msg = 'Favicon couldn\'t be uploaded from URL.';
					}
				} else if ( $this->mbpfavicon_request['link_type'] == 2 ) { // Upload from local computer
					$mfi_upload_path   = $this->mbpfaviconMakeDir($mfi_dir);
					$upload_1_name     = $_FILES['favicon_upload_1']['name'];
					$upload_1_type     = $_FILES['favicon_upload_1']['type'];
					$upload_1_size     = $_FILES['favicon_upload_1']['size'];
					$upload_1_tmp_name = $_FILES['favicon_upload_1']['tmp_name'];
					$mfi_favicon_path  = $mfi_upload_path.'/'.$upload_1_name;
					$mfi_favicon_url   = $this->siteurl.'/wp-content/'.$mfi_dir.'/'.$upload_1_name; 
					if ( in_array($upload_1_type,$mfi_valid_file) ) {
						if ( move_uploaded_file($upload_1_tmp_name, $mfi_favicon_path) ) {
							$mfi_msg = 'Favicon uploaded from local computer and activated.';
						} else {
							$mfi_msg = 'Favicon couldn\'t be uploaded from local computer.';
						}
					} else {
						$mfi_msg = 'Favicon couldn\'t be uploaded from local computer. Invalid file type.';
					}
					$this->mbpfavicon = $mfi_favicon_url;
				} else { // Use own link
					$this->mbpfavicon = $this->mbpfavicon_request['favicon'];
					$mfi_msg = 'Favicon activated.';
				}
				update_option("mbp_favicon", $this->mbpfavicon);
				echo '<div id="message" class="updated fade"><p><strong>'. __($mfi_msg, 'mbpfavicon') .'</strong></p></div>';
			}
			// create an array of icons
			$icons_array = array();
			if ( $dir = opendir($this->mbpfavicon_dir_path) ) {
				while ( ($file = readdir($dir)) !== false ) {
					if ( $file != "." && $file != ".." ) {
						$file_info = pathinfo($file);
						if ( $file_info['extension'] == 'ico' )
							$icons_array[] = $file;
					}
				}
				closedir($dir);
			}
			if ( trim($this->mbpfavicon) == '' ) {
				$mbpfavicon_curr_img = $this->mbpfavicon_fullpath.'1x1.gif';
			} else {
				$mbpfavicon_curr_img = $this->mbpfavicon;
			}
			if ( strpos($_SERVER['HTTP_USER_AGENT'],'MSIE') === false ) { 
				$icon_span_style = 'style="padding:4px 5px 6px 5px;background-color:#dddddd;"';
				$icon_style = '';
			} else {
				$icon_span_style = 'style="background-color:#dddddd;"';
				$icon_style = 'style="padding:5px 4px 4px 4px;"';
			}
			?>
			<script type="text/javascript">
			<!--
			function selectIcon(icon) {
				document.getElementById('mbpfavicon_curr').value   = icon.src;
				document.getElementById('mbpfavicon_curr_img').src = icon.src;
			}
			function bgColorAlter(cell, onfocus) {
				if ( onfocus == 1 ) {
					cell.style.backgroundColor = '#dddddd';
				} else {
					cell.style.backgroundColor = '#f1f1f1';
				}
			}
			function mfiSwitchType(curr) {
				var mfi_type_1  = document.getElementById('mfi_type_1');
				var mfi_type_2  = document.getElementById('mfi_type_2');
				var mfi_type_3  = document.getElementById('mfi_type_3');
				var mfi_icon    = document.getElementById('mfi_icon');
				var mfi_icon_td = document.getElementById('mfi_icon_td');
				if ( curr == 1 ) {
				    mfi_icon_td.style.width  = '6%';
					mfi_icon.style.display   = 'block';
					mfi_type_1.style.display = 'block';
					mfi_type_2.style.display = 'none';
					mfi_type_3.style.display = 'none';
				} else if ( curr == 2 ) {
				    mfi_icon_td.style.width  = '1%';
					mfi_icon.style.display   = 'none';
					mfi_type_1.style.display = 'none';
					mfi_type_2.style.display = 'block';
					mfi_type_3.style.display = 'none';
				} else if ( curr == 3 ) {
				    mfi_icon_td.style.width  = '1%';
					mfi_icon.style.display   = 'none';
					mfi_type_1.style.display = 'none';
					mfi_type_2.style.display = 'none';
					mfi_type_3.style.display = 'block';
				}
			}
			//--></script>
			<div class="wrap"><h2> <?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?></h2>
			 <strong><a href="http://www.maxblogpress.com/plugins/mfi/mfi-use/" target="_blank"><?php _e('How to use it?', 'mbpfavicon'); ?></a></strong> | 
			 <strong><a href="http://www.maxblogpress.com/plugins/mfi/mfi-comments/" target="_blank"><?php _e('Comments and Suggestions', 'mbpfavicon'); ?></a></strong><br /><br />
			 <form method="post" action="" enctype="multipart/form-data">
			 <p>
			 <table border="0" width="100%" cellpadding="1" cellspacing="1" bgcolor="#ffffff">
			  <tr>
			   <td>&nbsp;</td>
			   <td>
			   <input type="radio" name="mbpfavicon[link_type]" id="link_type_1" value="1" <?php echo 'checked';?> onclick="mfiSwitchType(1)" /> Favicon Link &nbsp;    
			   <input type="radio" name="mbpfavicon[link_type]" id="link_type_2" value="2" onclick="mfiSwitchType(2)" /> Upload Favicon From My Computer &nbsp;     
			   <input type="radio" name="mbpfavicon[link_type]" id="link_type_3" value="3" onclick="mfiSwitchType(3)" /> Upload From URL &nbsp; 
			   </td>
			  </tr>
			  <tr>
			   <td width="105"><strong><?php _e('Favorite Icon', 'mbpfavicon'); ?>: </strong></td>
			   <td>
			    <table width="100%" border="0">
				 <tr>
				  <td width="1%" id="mfi_type_1" style="display:block">
			      <input type="text" name="mbpfavicon[favicon]" id="mbpfavicon_curr" value="<?php echo $this->mbpfavicon;?>" size="45">
			      </td>
				  <td width="1%" id="mfi_type_2" style="display:none">
				  <input type="file" name="favicon_upload_1" id="favicon_upload_1" value="" size="25">
				  </td>
				  <td width="1%" id="mfi_type_3" style="display:none">
			      <input type="text" name="mbpfavicon[favicon_upload_2]" id="favicon_upload_2" value="" size="45">
				  </td>
				  <td id="mfi_icon_td" width="6%">
			      <span id="mfi_icon" <?php echo $icon_span_style;?>><img src="<?php echo $mbpfavicon_curr_img;?>" id="mbpfavicon_curr_img" width="16" height="16" border="0" align="absmiddle" <?php echo $icon_style;?> /></span>
				  </td>
				  <td width="91%">
				  <input type="submit" name="mbpfavicon[save]" value="<?php _e('Save', 'mbpfavicon'); ?>" class="button" />
				  </td>
                 </tr>
				</table>
			   </td>
			  </tr>
			 </table>
			 </p>
			 <p>
			 <strong><?php _e('Choose the favorite icon you want to use', 'mbpfavicon'); ?>: </strong>
			 <table border="0" width="300" cellpadding="8" cellspacing="3" bgcolor="#ffffff">
			 <?php 
			 $i = 0;
			 foreach ( $icons_array as $icon ) { 
				if ( $i == 0 ) print '<tr bgcolor="#f1f1f1">';
				else if ( $i%10 == 0 ) print '</tr><tr bgcolor="#f1f1f1">';
				$i++;
				print '<td width="30" onmouseover="bgColorAlter(this,1);" onmouseout="bgColorAlter(this,0);"><img src="'.$this->mbpfavicon_fullpath.$icon.'" onclick="selectIcon(this);" style="cursor:hand;cursor:pointer;border:0"></td>';
			 } 
			 ?>
			 </table>
			 </p>
			 </form>
			 <p>
			 <strong><?php _e('Not happy with the above icons? You can get more free icons from these websites', 'mbpfavicon'); ?>: </strong><br />
			 <a href="http://www.vistaicons.com/" target="_blank">Vista Icons</a><br />
			 <a href="http://www.famfamfam.com/" target="_blank">FAMFAMFAM</a><br />
			 <a href="http://www.free-icons.co.uk/" target="_blank">Free Icons</a><br />
			 <a href="http://www.iconarchive.com/" target="_blank">Icon Archive</a><br />
			 </p>
			 <p style="text-align:center;margin-top:3em;"><strong><?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?> by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>
			</div>
			<?php
		}
	}
	
	/**
	 * Plugin registration form
	 * @access public 
	 */
	function mfiRegistrationForm($form_name, $submit_btn_txt='Register', $name, $email, $hide=0, $submit_again='') {
		$wp_url = get_bloginfo('wpurl');
		$wp_url = (strpos($wp_url,'http://') === false) ? get_bloginfo('siteurl') : $wp_url;
		$thankyou_url = $wp_url.'/wp-admin/options-general.php?page='.$_GET['page'];
		$onlist_url   = $wp_url.'/wp-admin/options-general.php?page='.$_GET['page'].'&amp;mbp_onlist=1';
		if ( $hide == 1 ) $align_tbl = 'left';
		else $align_tbl = 'center';
		?>
		
		<?php if ( $submit_again != 1 ) { ?>
		<script><!--
		function trim(str){
			var n = str;
			while ( n.length>0 && n.charAt(0)==' ' ) 
				n = n.substring(1,n.length);
			while( n.length>0 && n.charAt(n.length-1)==' ' )	
				n = n.substring(0,n.length-1);
			return n;
		}
		function mfiValidateForm_0() {
			var name = document.<?php echo $form_name;?>.name;
			var email = document.<?php echo $form_name;?>.from;
			var reg = /^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/;
			var err = ''
			if ( trim(name.value) == '' )
				err += '- Name Required\n';
			if ( reg.test(email.value) == false )
				err += '- Valid Email Required\n';
			if ( err != '' ) {
				alert(err);
				return false;
			}
			return true;
		}
		//-->
		</script>
		<?php } ?>
		<table align="<?php echo $align_tbl;?>">
		<form name="<?php echo $form_name;?>" method="post" action="http://www.aweber.com/scripts/addlead.pl" <?php if($submit_again!=1){;?>onsubmit="return mfiValidateForm_0()"<?php }?>>
		 <input type="hidden" name="unit" value="maxbp-activate">
		 <input type="hidden" name="redirect" value="<?php echo $thankyou_url;?>">
		 <input type="hidden" name="meta_redirect_onlist" value="<?php echo $onlist_url;?>">
		 <input type="hidden" name="meta_adtracking" value="mfi-m-activate">
		 <input type="hidden" name="meta_message" value="1">
		 <input type="hidden" name="meta_required" value="from,name">
	 	 <input type="hidden" name="meta_forward_vars" value="1">	
		 <?php if ( $submit_again != '' ) { ?> 	
		 <input type="hidden" name="submit_again" value="1">
		 <?php } ?>		 
		 <?php if ( $hide == 1 ) { ?> 
		 <input type="hidden" name="name" value="<?php echo $name;?>">
		 <input type="hidden" name="from" value="<?php echo $email;?>">
		 <?php } else { ?>
		 <tr>
		  <td>Name: </td><td><input type="text" name="name" value="<?php echo $name;?>" size="25" maxlength="150" /></td>
		 </tr>
		 <tr>
		  <td>Email: </td><td><input type="text" name="from" value="<?php echo $email;?>" size="25" maxlength="150" /></td>
		 </tr>
		 <?php } ?>
		 <tr>
		  <td>&nbsp;</td><td><input type="submit" name="submit" value="<?php echo $submit_btn_txt;?>" class="button" /></td>
		 </tr>
		 </form>
		</table>
		<?php
	}
	
	/**
	 * Register Plugin - Step 2
	 * @access public 
	 */
	function mfiRegister_2($form_name='frm2',$name,$email) {
		$msg = 'You have not clicked on the confirmation link yet. A confirmation email has been sent to you again. Please check your email and click on the confirmation link to activate the plugin.';
		if ( trim($_GET['submit_again']) != '' && $msg != '' ) {
			echo '<div id="message" class="updated fade"><p><strong>'.$msg.'</strong></p></div>';
		}
		?>
		<div class="wrap"><h2> <?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?></h2>
		 <center>
		 <table width="640" cellpadding="5" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
		  <tr>
		   <td align="center"><h3>Almost Done....</h3></td>
		  </tr>
		  <tr>
		   <td><h3>Step 1:</h3></td>
		  </tr>
		  <tr>
		   <td>A confirmation email has been sent to your email "<?php echo $email;?>". You must click on the link inside the email to activate the plugin.</td>
		  </tr>
		  <tr>
		   <td><strong>The confirmation email will look like:</strong><br /><img src="http://www.maxblogpress.com/images/activate-plugin-email.jpg" vspace="4" border="0" /></td>
		  </tr>
		  <tr><td>&nbsp;</td></tr>
		  <tr>
		   <td><h3>Step 2:</h3></td>
		  </tr>
		  <tr>
		   <td>Click on the button below to Verify and Activate the plugin.</td>
		  </tr>
		  <tr>
		   <td><?php $this->mfiRegistrationForm($form_name.'_0','Verify and Activate',$name,$email,$hide=1,$submit_again=1);?></td>
		  </tr>
		 </table>
		 <p>&nbsp;</p>
		 <table width="640" cellpadding="5" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
           <tr>
             <td><h3>Troubleshooting</h3></td>
           </tr>
           <tr>
             <td><strong>The confirmation email is not there in my inbox!</strong></td>
           </tr>
           <tr>
             <td>Dont panic! CHECK THE JUNK, spam or bulk folder of your email.</td>
           </tr>
           <tr>
             <td>&nbsp;</td>
           </tr>
           <tr>
             <td><strong>It's not there in the junk folder either.</strong></td>
           </tr>
           <tr>
             <td>Sometimes the confirmation email takes time to arrive. Please be patient. WAIT FOR 6 HOURS AT MOST. The confirmation email should be there by then.</td>
           </tr>
           <tr>
             <td>&nbsp;</td>
           </tr>
           <tr>
             <td><strong>6 hours and yet no sign of a confirmation email!</strong></td>
           </tr>
           <tr>
             <td>Please register again from below:</td>
           </tr>
           <tr>
             <td><?php $this->mfiRegistrationForm($form_name,'Register Again',$name,$email,$hide=0,$submit_again=2);?></td>
           </tr>
           <tr>
             <td><strong>Help! Still no confirmation email and I have already registered twice</strong></td>
           </tr>
           <tr>
             <td>Okay, please register again from the form above using a DIFFERENT EMAIL ADDRESS this time.</td>
           </tr>
           <tr>
             <td>&nbsp;</td>
           </tr>
           <tr>
             <td><strong>Why am I receiving an error similar to the one shown below?</strong><br />
                 <img src="http://www.maxblogpress.com/images/no-verification-error.jpg" border="0" vspace="8" /><br />
               You get that kind of error when you click on &quot;Verify and Activate&quot; button or try to register again.<br />
               <br />
               This error means that you have already subscribed but have not yet clicked on the link inside confirmation email. In order to  avoid any spam complain we don't send repeated confirmation emails. If you have not recieved the confirmation email then you need to wait for 12 hours at least before requesting another confirmation email. </td>
           </tr>
           <tr>
             <td>&nbsp;</td>
           </tr>
           <tr>
             <td><strong>But I've still got problems.</strong></td>
           </tr>
           <tr>
             <td>Stay calm. <strong><a href="http://www.maxblogpress.com/contact-us/" target="_blank">Contact us</a></strong> about it and we will get to you ASAP.</td>
           </tr>
         </table>
		 </center>		
		<p style="text-align:center;margin-top:3em;"><strong><?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?> by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>
	    </div>
		<?php
	}

	/**
	 * Register Plugin - Step 1
	 * @access public 
	 */
	function mfiRegister_1($form_name='frm1') {
		global $userdata;
		$name  = trim($userdata->first_name.' '.$userdata->last_name);
		$email = trim($userdata->user_email);
		?>
		<div class="wrap"><h2> <?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?></h2>
		 <center>
		 <table width="620" cellpadding="3" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
		  <tr>
		   <td align="center"><h3>Please register the plugin to activate it. (Registration is free)</h3></td>
		  </tr>
		  <tr>
		   <td align="left">In addition you'll receive complimentary subscription to MaxBlogPress Newsletter which will give you many tips and tricks to attract lots of visitors to your blog.</td> 
		  </tr>
		  <tr>
		   <td align="center"><strong>Fill the form below to register the plugin:</strong></td>
		  </tr>
		  <tr>
		   <td><?php $this->mfiRegistrationForm($form_name,'Register',$name,$email);?></td>
		  </tr>
		  <tr>
		   <td align="center"><font size="1">[ Your contact information will be handled with the strictest confidence <br />and will never be sold or shared with third parties ]</font></td></td>
		  </tr>
		 </table>
		 </center>
		<p style="text-align:center;margin-top:3em;"><strong><?php echo MBPFAVICON_NAME.' '.MBPFAVICON_VERSION; ?> by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>
	    </div>
		<?php
	}
		
} // Eof Class

$MBPFavIcon = new MBPFavIcon();
?>